# -*- coding: utf-8 -*-
# © 2015 ACSONE SA/NV
# License LGPLv3 (http://www.gnu.org/licenses/lgpl-3.0-standalone.html)

import warnings

from .core import (
    prepare_odoo_addon,
    prepare_odoo_addons,
)


def _set_dist_keywords(dist, setup_keywords):
    # got this trick from pbr
    for key, val in setup_keywords.items():
        if hasattr(dist.metadata, key):
            if getattr(dist.metadata, key) is None:
                setattr(dist.metadata, key, val)
        elif hasattr(dist, key):
            if getattr(dist, key) is None:
                setattr(dist, key, val)
        else:
            msg = 'Unknown distribution option: %s' % repr(key)
            warnings.warn(msg)


def _parse_options(value):
    depends_override = {}
    external_dependencies_override = {}
    odoo_version_override = None
    if isinstance(value, dict):
        depends_override = \
            value.get('depends_override', {})
        external_dependencies_override = \
            value.get('external_dependencies_override', {})
        odoo_version_override = \
            value.get('odoo_version_override')
    return (
        depends_override,
        external_dependencies_override,
        odoo_version_override,
    )


def odoo_addon(dist, attr, value):
    depends_override, external_dependencies_override, odoo_version_override = \
        _parse_options(value)
    setup_keywords = prepare_odoo_addon(
        depends_override=depends_override,
        external_dependencies_override=external_dependencies_override,
        odoo_version_override=odoo_version_override,
    )
    _set_dist_keywords(dist, setup_keywords)


def odoo_addons(dist, attr, value):
    depends_override, external_dependencies_override, odoo_version_override = \
        _parse_options(value)
    setup_keywords = prepare_odoo_addons(
        depends_override=depends_override,
        external_dependencies_override=external_dependencies_override,
        odoo_version_override=odoo_version_override,
    )
    _set_dist_keywords(dist, setup_keywords)



# -*- coding: utf-8 -*-
# © 2015 ACSONE SA/NV
# License LGPLv3 (http://www.gnu.org/licenses/lgpl-3.0-standalone.html)

import os
import pkg_resources
import shutil
import subprocess
import sys
import unittest

from . import DATA_DIR


class TestSetupKeywords(unittest.TestCase):
    """ test the new setup() keywords (odoo_addon, odoo_addons) """

    def test_odoo_addon1(self):
        addon1_dir = os.path.join(DATA_DIR, 'setup_reusable_addons', 'addon1')
        subprocess.check_call([sys.executable, 'setup.py', 'egg_info'],
                              cwd=addon1_dir)
        egg_info_dir = os.path.join(addon1_dir,
                                    'odoo_addon_addon1.egg-info')
        assert os.path.isdir(egg_info_dir)
        try:
            dist = pkg_resources.find_distributions(addon1_dir).next()
            self.assertEquals(dist.key, 'odoo-addon-addon1')
            self.assertEquals(dist.requires(),
                              [pkg_resources.Requirement.parse(r) for r in
                               ['odoo>=8.0a,<9.0a']])
            self.assertTrue(dist.has_metadata('not-zip-safe'))
            self.assertEquals(dist.version, "8.0.1.0.0.99.dev1")
        finally:
            shutil.rmtree(egg_info_dir)

    def test_odoo_addon2(self):
        addon2_dir = os.path.join(DATA_DIR, 'setup_reusable_addons', 'addon2')
        subprocess.check_call([sys.executable, 'setup.py', 'egg_info'],
                              cwd=addon2_dir)
        egg_info_dir = os.path.join(addon2_dir,
                                    'odoo_addon_addon2.egg-info')
        assert os.path.isdir(egg_info_dir)
        try:
            dist = pkg_resources.find_distributions(addon2_dir).next()
            self.assertEquals(dist.key, 'odoo-addon-addon2')
            self.assertEquals(dist.requires(),
                              [pkg_resources.Requirement.parse(r) for r in
                               ['odoo-addon-addon1>=8.0a,<9.0a',
                                'odoo>=8.0a,<9.0a',
                                'python-dateutil']])
            self.assertTrue(dist.has_metadata('not-zip-safe'))
            self.assertEquals(dist.version, "8.0.1.0.1")
        finally:
            shutil.rmtree(egg_info_dir)

    def test_odoo_addon4(self):
        addon4_dir = os.path.join(DATA_DIR, 'setup_reusable_addons', 'addon4')
        subprocess.check_call([sys.executable, 'setup.py', 'egg_info'],
                              cwd=addon4_dir)
        egg_info_dir = os.path.join(addon4_dir,
                                    'odoo_addon_addon4.egg-info')
        assert os.path.isdir(egg_info_dir)
        try:
            dist = pkg_resources.find_distributions(addon4_dir).next()
            self.assertEquals(dist.key, 'odoo-addon-addon4')
            self.assertEquals(dist.requires(),
                              [pkg_resources.Requirement.parse(r) for r in
                               ['astropy>=1.0',
                                'odoo-addon-addon1>=8.0.3.0.0,<9.0a',
                                'odoo>=8.0a,<9.0a',
                                'python-dateutil']])
            self.assertTrue(dist.has_metadata('not-zip-safe'))
            self.assertEquals(dist.version, "8.0.2.0.0")
        finally:
            shutil.rmtree(egg_info_dir)

    def test_odoo_addon5(self):
        addon5_dir = os.path.join(DATA_DIR, 'setup_reusable_addons', 'addon5')
        subprocess.check_call([sys.executable, 'setup.py', 'egg_info'],
                              cwd=addon5_dir)
        egg_info_dir = os.path.join(addon5_dir,
                                    'odoo_addon_addon5.egg-info')
        assert os.path.isdir(egg_info_dir)
        try:
            dist = pkg_resources.find_distributions(addon5_dir).next()
            self.assertEquals(dist.key, 'odoo-addon-addon5')
        finally:
            shutil.rmtree(egg_info_dir)

    def test_custom_project(self):
        project_dir = os.path.join(DATA_DIR, 'setup_custom_project')
        subprocess.check_call([sys.executable, 'setup.py', 'egg_info'],
                              cwd=project_dir)
        egg_info_dir = os.path.join(project_dir,
                                    'test_custom_project.egg-info')
        assert os.path.isdir(egg_info_dir)
        dist = pkg_resources.find_distributions(project_dir).next()
        self.assertFalse(dist.has_metadata('not-zip-safe'))
        shutil.rmtree(egg_info_dir)


if __name__ == '__main__':
    unittest.main()



# -*- coding: utf-8 -*-
# © 2015 ACSONE SA/NV
# License LGPLv3 (http://www.gnu.org/licenses/lgpl-3.0-standalone.html)
import os

DATA_DIR = os.path.join(os.path.dirname(os.path.abspath(__file__)), 'data')


class WorkingDirectoryKeeper(object):
    """A context manager to get back the working directory as it was before.
    If you want to stack working directory keepers, you need a new instance
    for each stage.
    """

    active = False

    def __enter__(self):
        if self.active:
            raise RuntimeError("Already in a working directory keeper !")
        self.wd = os.getcwd()
        self.active = True

    def __exit__(self, *exc_args):
        os.chdir(self.wd)
        self.active = False


working_directory_keeper = WorkingDirectoryKeeper()



# -*- coding: utf-8 -*-
# © 2015 ACSONE SA/NV
# License LGPLv3 (http://www.gnu.org/licenses/lgpl-3.0-standalone.html)
import os
import unittest

from setuptools_odoo.core import (
    prepare_odoo_addon,
    prepare_odoo_addons,
    make_pkg_name,
    make_pkg_requirement,
)

from . import DATA_DIR, working_directory_keeper


class TestPrepare(unittest.TestCase):
    """ Test the prepare... public api """

    def test_make_pkg_name(self):
        pkg_name = make_pkg_name('addon1')
        self.assertEquals(pkg_name, 'odoo-addon-addon1')

    def test_make_pkg_requirement(self):
        addon_dir = os.path.join(DATA_DIR, 'addon1')
        requirement = make_pkg_requirement(addon_dir)
        self.assertEquals(requirement, 'odoo-addon-addon1>=8.0a,<9.0a')

    def test_addon1(self):
        addon_dir = os.path.join(DATA_DIR, 'setup_reusable_addons', 'addon1')
        with working_directory_keeper:
            os.chdir(addon_dir)
            keywords = prepare_odoo_addon()
            self.assertEquals(keywords, {
                'description': 'addon 1 summary',
                'include_package_data': True,
                'install_requires': ['odoo>=8.0a,<9.0a'],
                'license': 'AGPL-3',
                'long_description': 'addon 1 readme content\n',
                'name': 'odoo-addon-addon1',
                'namespace_packages': ['odoo_addons'],
                'packages': ['odoo_addons'],
                'url': 'https://acsone.eu/',
                'version': '8.0.1.0.0.99.dev1',
                'zip_safe': False,
            })

    def test_addon2(self):
        addon_dir = os.path.join(DATA_DIR, 'setup_reusable_addons', 'addon2')
        with working_directory_keeper:
            os.chdir(addon_dir)
            keywords = prepare_odoo_addon()
            self.assertEquals(keywords, {
                'description': 'addon 2 summary',
                'include_package_data': True,
                'install_requires': ['odoo-addon-addon1>=8.0a,<9.0a',
                                     'odoo>=8.0a,<9.0a',
                                     'python-dateutil'],
                'name': 'odoo-addon-addon2',
                'namespace_packages': ['odoo_addons'],
                'packages': ['odoo_addons'],
                'version': '8.0.1.0.1',
                'zip_safe': False,
            })

    def test_addons_dir(self):
        addons_dir = os.path.join(DATA_DIR, 'setup_custom_project')
        with working_directory_keeper:
            os.chdir(addons_dir)
            keywords = prepare_odoo_addons()
            self.assertEquals(keywords, {
                'include_package_data': True,
                'install_requires': ['odoo>=8.0a,<9.0a',
                                     'python-dateutil'],
                'namespace_packages': ['odoo_addons'],
                'packages': ['odoo_addons'],
                'zip_safe': False,
            })


if __name__ == '__main__':
    unittest.main()



# -*- coding: utf-8 -*-
# © 2015 ACSONE SA/NV
# License LGPLv3 (http://www.gnu.org/licenses/lgpl-3.0-standalone.html)

import os
import setuptools
from distutils.core import DistutilsSetupError
from warnings import warn

from . import base_addons
from . import external_dependencies
from .manifest import read_manifest, is_installable_addon
from .git_postversion import get_git_postversion


ADDON_PKG_NAME_PREFIX = 'odoo-addon-'

ADDONS_NAMESPACE = 'odoo_addons'

ODOO_VERSION_INFO = {
    '8.0': {
        'odoo_dep': 'odoo>=8.0a,<9.0a',
        'base_addons': base_addons.odoo8,
        'addon_dep_version': '>=8.0a,<9.0a',
    },
    '9.0': {
        'odoo_dep': 'odoo>=9.0a,<9.1a',
        'base_addons': base_addons.odoo9,
        'addon_dep_version': '>=9.0a,<9.1a',
    },
}


def _get_version(addon_dir, manifest, odoo_version_override=None):
    version = manifest.get('version')
    if not version:
        warn("No version in manifest in %s" % addon_dir)
        version = '0.0.0'
    if not odoo_version_override:
        if len(version.split('.')) < 5:
            raise DistutilsSetupError("Version in manifest must have at least "
                                      "5 components and start with "
                                      "the Odoo series number in %s" %
                                      addon_dir)
        odoo_version = '.'.join(version.split('.')[:2])
        if odoo_version not in ODOO_VERSION_INFO:
            raise DistutilsSetupError("Unsupported odoo version '%s' in %s" %
                                      (odoo_version, addon_dir))
    else:
        odoo_version = odoo_version_override
    odoo_version_info = ODOO_VERSION_INFO[odoo_version]
    version = get_git_postversion(addon_dir)
    return version, odoo_version_info


def _get_description(addon_dir, manifest):
    return manifest.get('summary', '').strip() or manifest.get('name').strip()


def _get_long_description(addon_dir, manifest):
    readme_path = os.path.join(addon_dir, 'README.rst')
    if os.path.exists(readme_path):
        return open(readme_path).read()
    else:
        return manifest.get('description')


def make_pkg_name(addon_name):
    return ADDON_PKG_NAME_PREFIX + addon_name


def make_pkg_requirement(addon_dir, odoo_version_override=None):
    manifest = read_manifest(addon_dir)
    addon_name = os.path.basename(addon_dir)
    version, odoo_version_info = _get_version(addon_dir,
                                              manifest,
                                              odoo_version_override)
    addon_dep_version = odoo_version_info['addon_dep_version']
    return make_pkg_name(addon_name) + addon_dep_version


def _get_install_requires(odoo_version_info,
                          manifest,
                          no_depends=[],
                          depends_override={},
                          external_dependencies_override={}):
    # dependency on Odoo
    install_requires = [odoo_version_info['odoo_dep']]
    # dependencies on other addons (except Odoo official addons)
    addon_dep_version = odoo_version_info['addon_dep_version']
    base_addons = odoo_version_info['base_addons']
    for depend in manifest.get('depends', []):
        if depend in base_addons:
            continue
        if depend in no_depends:
            continue
        if depend in depends_override:
            install_require = depends_override[depend]
        else:
            install_require = make_pkg_name(depend) + addon_dep_version
        install_requires.append(install_require)
    # python external_dependencies
    for dep in manifest.get('external_dependencies', {}).get('python', []):
        if dep in external_dependencies_override.get('python', {}):
            dep = external_dependencies_override.get('python', {})[dep]
        else:
            dep = external_dependencies.EXTERNAL_DEPENDENCIES_MAP.get(dep, dep)
        install_requires.append(dep)
    return sorted(install_requires)


def get_install_requires_odoo_addon(addon_dir,
                                    no_depends=[],
                                    depends_override={},
                                    external_dependencies_override={},
                                    odoo_version_override=None):
    """ Get the list of requirements for an addon """
    manifest = read_manifest(addon_dir)
    version, odoo_version_info = _get_version(addon_dir,
                                              manifest,
                                              odoo_version_override)
    return _get_install_requires(odoo_version_info,
                                 manifest,
                                 no_depends,
                                 depends_override,
                                 external_dependencies_override)


def get_install_requires_odoo_addons(addons_dir,
                                     depends_override={},
                                     external_dependencies_override={},
                                     odoo_version_override=None):
    """ Get the list of requirements for a directory containing addons """
    addon_dirs = []
    addons = os.listdir(addons_dir)
    for addon in addons:
        addon_dir = os.path.join(addons_dir, addon)
        if is_installable_addon(addon_dir):
            addon_dirs.append(addon_dir)
    install_requires = set()
    for addon_dir in addon_dirs:
        r = get_install_requires_odoo_addon(
            addon_dir,
            no_depends=addons,
            depends_override=depends_override,
            external_dependencies_override=external_dependencies_override,
            odoo_version_override=odoo_version_override,
        )
        install_requires.update(r)
    return sorted(install_requires)


def prepare_odoo_addon(depends_override={},
                       external_dependencies_override={},
                       odoo_version_override=None):
    addons_dir = ADDONS_NAMESPACE
    potential_addons = os.listdir(addons_dir)
    # list installable addons, except auto-installable ones
    # in case we want to combine an addon and it's glue modules
    # in a package named after the main addon
    addons = [a for a in potential_addons
              if is_installable_addon(os.path.join(addons_dir, a),
                                      unless_auto_installable=True)]
    if len(addons) == 0:
        # if no addon is found, it may mean we are trying to package
        # a single module that is marked auto-install, so let's try
        # listing all installable modules
        addons = [a for a in potential_addons
                  if is_installable_addon(os.path.join(addons_dir, a))]
    if len(addons) != 1:
        raise DistutilsSetupError('%s must contain exactly one '
                                  'installable Odoo addon dir' %
                                  os.path.abspath(addons_dir))
    addon_name = addons[0]
    addon_dir = os.path.join(ADDONS_NAMESPACE, addon_name)
    manifest = read_manifest(addon_dir)
    version, odoo_version_info = _get_version(addon_dir,
                                              manifest,
                                              odoo_version_override)
    install_requires = get_install_requires_odoo_addon(
        addon_dir,
        depends_override=depends_override,
        external_dependencies_override=external_dependencies_override,
        odoo_version_override=odoo_version_override,
    )
    setup_keywords = {
        'name': make_pkg_name(addon_name),
        'version': version,
        'description': _get_description(addon_dir, manifest),
        'long_description': _get_long_description(addon_dir, manifest),
        'url': manifest.get('website'),
        'license': manifest.get('license'),
        'packages': setuptools.find_packages(),
        'include_package_data': True,
        'namespace_packages': [ADDONS_NAMESPACE],
        'zip_safe': False,
        'install_requires': install_requires,
        # TODO: keywords, classifiers, authors
    }
    # import pprint; pprint.pprint(setup_keywords)
    return {k: v for k, v in setup_keywords.items() if v is not None}


def prepare_odoo_addons(depends_override={},
                        external_dependencies_override={},
                        odoo_version_override=None):
    addons_dir = ADDONS_NAMESPACE
    install_requires = get_install_requires_odoo_addons(
        addons_dir,
        depends_override=depends_override,
        external_dependencies_override=external_dependencies_override,
        odoo_version_override=odoo_version_override,
    )
    setup_keywords = {
        'packages': setuptools.find_packages(),
        'include_package_data': True,
        'namespace_packages': [ADDONS_NAMESPACE],
        'zip_safe': False,
        'install_requires': install_requires,
    }
    # import pprint; pprint.pprint(setup_keywords)
    return {k: v for k, v in setup_keywords.items() if v is not None}



# -*- coding: utf-8 -*-
# © 2015 ACSONE SA/NV
# License LGPLv3 (http://www.gnu.org/licenses/lgpl-3.0-standalone.html)


from .core import (
    prepare_odoo_addon,
    prepare_odoo_addons,
    get_install_requires_odoo_addon,
    get_install_requires_odoo_addons,
    make_pkg_name,
    make_pkg_requirement,
)


__all__ = [
    prepare_odoo_addon.__name__,
    prepare_odoo_addons.__name__,
    get_install_requires_odoo_addon.__name__,
    get_install_requires_odoo_addons.__name__,
    make_pkg_name.__name__,
    make_pkg_requirement.__name__,
]



import setuptools

setuptools.setup(
    setup_requires=['setuptools-odoo'],
    odoo_addon={
        'depends_override': {
            'addon1': 'odoo-addon-addon1>=8.0.3.0.0,<9.0a',
        },
        'external_dependencies_override': {
            'python': {
                'astropy': 'astropy>=1.0',
            },
        },
    },
)



import setuptools

setuptools.setup(
    name='test-custom-project',
    version='0.9.0',
    setup_requires=['setuptools-odoo'],
    odoo_addons=True,
    # force zip_safe which would otherwise be set to False via odoo_addons=True
    zip_safe=True,
)



# -*- coding: utf-8 -*-
# © 2015 ACSONE SA/NV
# License LGPLv3 (http://www.gnu.org/licenses/lgpl-3.0-standalone.html)
""" List of Odoo official addons which are not released as individual packages.
They are therefore considered as installed as soon as the 'odoo' dependency
is satisfied. """

odoo8 = {
    'base',
    'account',
    'account_accountant',
    'account_analytic_analysis',
    'account_analytic_default',
    'account_analytic_plans',
    'account_anglo_saxon',
    'account_asset',
    'account_bank_statement_extensions',
    'account_budget',
    'account_cancel',
    'account_chart',
    'account_check_writing',
    'account_followup',
    'account_payment',
    'account_sequence',
    'account_test',
    'account_voucher',
    'analytic',
    'analytic_contract_hr_expense',
    'analytic_user_function',
    'anonymization',
    'association',
    'auth_crypt',
    'auth_ldap',
    'auth_oauth',
    'auth_openid',
    'auth_signup',
    'base_action_rule',
    'base_gengo',
    'base_geolocalize',
    'base_iban',
    'base_import',
    'base_import_module',
    'base_report_designer',
    'base_setup',
    'base_vat',
    'board',
    'bus',
    'calendar',
    'claim_from_delivery',
    'contacts',
    'crm',
    'crm_claim',
    'crm_helpdesk',
    'crm_mass_mailing',
    'crm_partner_assign',
    'crm_profiling',
    'crm_project_issue',
    'decimal_precision',
    'delivery',
    'document',
    'edi',
    'email_template',
    'event',
    'event_sale',
    'fetchmail',
    'fleet',
    'gamification',
    'gamification_sale_crm',
    'google_account',
    'google_calendar',
    'google_drive',
    'google_spreadsheet',
    'hr',
    'hr_applicant_document',
    'hr_attendance',
    'hr_contract',
    'hr_evaluation',
    'hr_expense',
    'hr_gamification',
    'hr_holidays',
    'hr_payroll',
    'hr_payroll_account',
    'hr_recruitment',
    'hr_timesheet',
    'hr_timesheet_invoice',
    'hr_timesheet_sheet',
    'hw_escpos',
    'hw_posbox_homepage',
    'hw_posbox_upgrade',
    'hw_proxy',
    'hw_scale',
    'hw_scanner',
    'im_chat',
    'im_livechat',
    'im_odoo_support',
    'knowledge',
    'l10n_ae',
    'l10n_ar',
    'l10n_at',
    'l10n_be',
    'l10n_be_coda',
    'l10n_be_hr_payroll',
    'l10n_be_hr_payroll_account',
    'l10n_be_intrastat',
    'l10n_be_invoice_bba',
    'l10n_bo',
    'l10n_br',
    'l10n_ca',
    'l10n_ch',
    'l10n_cl',
    'l10n_cn',
    'l10n_co',
    'l10n_cr',
    'l10n_de',
    'l10n_do',
    'l10n_ec',
    'l10n_es',
    'l10n_et',
    'l10n_eu_service',
    'l10n_fr',
    'l10n_fr_hr_payroll',
    'l10n_fr_rib',
    'l10n_gr',
    'l10n_gt',
    'l10n_hn',
    'l10n_hr',
    'l10n_hu',
    'l10n_in',
    'l10n_in_hr_payroll',
    'l10n_it',
    'l10n_jp',
    'l10n_lu',
    'l10n_ma',
    'l10n_multilang',
    'l10n_mx',
    'l10n_nl',
    'l10n_no',
    'l10n_pa',
    'l10n_pe',
    'l10n_pl',
    'l10n_pt',
    'l10n_ro',
    'l10n_sa',
    'l10n_sg',
    'l10n_si',
    'l10n_syscohada',
    'l10n_th',
    'l10n_tr',
    'l10n_uk',
    'l10n_us',
    'l10n_uy',
    'l10n_ve',
    'l10n_vn',
    'lunch',
    'mail',
    'marketing',
    'marketing_campaign',
    'marketing_campaign_crm_demo',
    'marketing_crm',
    'mass_mailing',
    'membership',
    'mrp',
    'mrp_byproduct',
    'mrp_operations',
    'mrp_repair',
    'multi_company',
    'note',
    'note_pad',
    'pad',
    'pad_project',
    'payment',
    'payment_adyen',
    'payment_authorize',
    'payment_buckaroo',
    'payment_ogone',
    'payment_paypal',
    'payment_sips',
    'payment_transfer',
    'point_of_sale',
    'portal',
    'portal_claim',
    'portal_gamification',
    'portal_project',
    'portal_project_issue',
    'portal_sale',
    'portal_stock',
    'pos_discount',
    'pos_restaurant',
    'procurement',
    'procurement_jit',
    'procurement_jit_stock',
    'product',
    'product_email_template',
    'product_expiry',
    'product_extended',
    'product_margin',
    'product_visible_discount',
    'project',
    'project_issue',
    'project_issue_sheet',
    'project_timesheet',
    'purchase',
    'purchase_analytic_plans',
    'purchase_double_validation',
    'purchase_requisition',
    'report',
    'report_intrastat',
    'report_webkit',
    'resource',
    'sale',
    'sale_analytic_plans',
    'sale_crm',
    'sale_journal',
    'sale_layout',
    'sale_margin',
    'sale_mrp',
    'sale_order_dates',
    'sale_service',
    'sale_stock',
    'sales_team',
    'share',
    'stock',
    'stock_account',
    'stock_dropshipping',
    'stock_invoice_directly',
    'stock_landed_costs',
    'stock_picking_wave',
    'subscription',
    'survey',
    'survey_crm',
    'warning',
    'web',
    'web_analytics',
    'web_api',
    'web_calendar',
    'web_diagram',
    'web_gantt',
    'web_graph',
    'web_kanban',
    'web_kanban_gauge',
    'web_kanban_sparkline',
    'web_linkedin',
    'web_tests',
    'web_tests_demo',
    'web_view_editor',
    'website',
    'website_blog',
    'website_certification',
    'website_crm',
    'website_crm_partner_assign',
    'website_customer',
    'website_event',
    'website_event_sale',
    'website_event_track',
    'website_forum',
    'website_forum_doc',
    'website_gengo',
    'website_google_map',
    'website_hr',
    'website_hr_recruitment',
    'website_instantclick',
    'website_livechat',
    'website_mail',
    'website_mail_group',
    'website_membership',
    'website_partner',
    'website_payment',
    'website_project',
    'website_quote',
    'website_report',
    'website_sale',
    'website_sale_delivery',
    'website_sale_options',
    'website_twitter',
}

odoo9c = {
    'base',
    'account',
    'account_accountant',
    'account_analytic_default',
    'account_asset',
    'account_bank_statement_import',
    'account_budget',
    'account_cancel',
    'account_check_printing',
    'account_tax_cash_basis',
    'account_tax_python',
    'account_test',
    'account_voucher',
    'analytic',
    'anonymization',
    'association',
    'auth_crypt',
    'auth_ldap',
    'auth_oauth',
    'auth_signup',
    'barcodes',
    'base_action_rule',
    'base_gengo',
    'base_geolocalize',
    'base_iban',
    'base_import',
    'base_import_module',
    'base_setup',
    'base_vat',
    'board',
    'bus',
    'calendar',
    'claim_from_delivery',
    'crm',
    'crm_claim',
    'crm_partner_assign',
    'crm_project_issue',
    'decimal_precision',
    'delivery',
    'document',
    'event',
    'event_sale',
    'fetchmail',
    'fleet',
    'gamification',
    'gamification_sale_crm',
    'google_account',
    'google_calendar',
    'google_drive',
    'google_spreadsheet',
    'hr',
    'hr_attendance',
    'hr_contract',
    'hr_equipment',
    'hr_expense',
    'hr_gamification',
    'hr_holidays',
    'hr_payroll',
    'hr_payroll_account',
    'hr_recruitment',
    'hr_timesheet',
    'hr_timesheet_sheet',
    'hw_escpos',
    'hw_posbox_homepage',
    'hw_posbox_upgrade',
    'hw_proxy',
    'hw_scale',
    'hw_scanner',
    'im_livechat',
    'im_odoo_support',
    'l10n_ae',
    'l10n_ar',
    'l10n_at',
    'l10n_au',
    'l10n_be',
    'l10n_be_hr_payroll',
    'l10n_be_hr_payroll_account',
    'l10n_be_intrastat',
    'l10n_be_invoice_bba',
    'l10n_bo',
    'l10n_br',
    'l10n_ca',
    'l10n_ch',
    'l10n_cl',
    'l10n_cn',
    'l10n_cn_small_business',
    'l10n_cn_standard',
    'l10n_co',
    'l10n_cr',
    'l10n_de',
    'l10n_de_skr03',
    'l10n_de_skr04',
    'l10n_do',
    'l10n_ec',
    'l10n_es',
    'l10n_et',
    'l10n_eu_service',
    'l10n_fr',
    'l10n_fr_hr_payroll',
    'l10n_generic_coa',
    'l10n_gr',
    'l10n_gt',
    'l10n_hn',
    'l10n_hr',
    'l10n_hu',
    'l10n_in',
    'l10n_in_hr_payroll',
    'l10n_it',
    'l10n_jp',
    'l10n_lu',
    'l10n_ma',
    'l10n_multilang',
    'l10n_mx',
    'l10n_nl',
    'l10n_no',
    'l10n_pa',
    'l10n_pe',
    'l10n_pl',
    'l10n_pt',
    'l10n_ro',
    'l10n_sa',
    'l10n_sg',
    'l10n_si',
    'l10n_syscohada',
    'l10n_th',
    'l10n_tr',
    'l10n_uk',
    'l10n_us',
    'l10n_uy',
    'l10n_ve',
    'l10n_vn',
    'link_tracker',
    'lunch',
    'mail',
    'mail_tip',
    'marketing',
    'marketing_campaign',
    'marketing_campaign_crm_demo',
    'mass_mailing',
    'membership',
    'mrp',
    'mrp_byproduct',
    'mrp_operations',
    'mrp_repair',
    'note',
    'note_pad',
    'pad',
    'pad_project',
    'payment',
    'payment_adyen',
    'payment_authorize',
    'payment_buckaroo',
    'payment_ogone',
    'payment_paypal',
    'payment_sips',
    'payment_transfer',
    'point_of_sale',
    'portal',
    'portal_gamification',
    'portal_sale',
    'portal_stock',
    'pos_cache',
    'pos_discount',
    'pos_mercury',
    'pos_reprint',
    'pos_restaurant',
    'procurement',
    'procurement_jit',
    'product',
    'product_email_template',
    'product_expiry',
    'product_extended',
    'product_margin',
    'product_uos',
    'product_visible_discount',
    'project',
    'project_issue',
    'project_issue_sheet',
    'project_timesheet',
    'purchase',
    'purchase_requisition',
    'rating',
    'rating_project',
    'rating_project_issue',
    'report',
    'report_intrastat',
    'report_webkit',
    'resource',
    'sale',
    'sale_crm',
    'sale_expense',
    'sale_layout',
    'sale_margin',
    'sale_mrp',
    'sale_order_dates',
    'sale_service',
    'sale_stock',
    'sale_timesheet',
    'sales_team',
    'stock',
    'stock_account',
    'stock_calendar',
    'stock_dropshipping',
    'stock_landed_costs',
    'stock_picking_wave',
    'subscription',
    'survey',
    'survey_crm',
    'theme_bootswatch',
    'theme_default',
    'utm',
    'warning',
    'web',
    'web_analytics',
    'web_calendar',
    'web_diagram',
    'web_editor',
    'web_kanban',
    'web_kanban_gauge',
    'web_planner',
    'web_settings_dashboard',
    'web_tip',
    'web_view_editor',
    'website',
    'website_blog',
    'website_crm',
    'website_crm_claim',
    'website_crm_partner_assign',
    'website_customer',
    'website_event',
    'website_event_questions',
    'website_event_sale',
    'website_event_track',
    'website_form',
    'website_forum',
    'website_forum_doc',
    'website_gengo',
    'website_google_map',
    'website_hr',
    'website_hr_recruitment',
    'website_issue',
    'website_links',
    'website_livechat',
    'website_mail',
    'website_mail_channel',
    'website_mass_mailing',
    'website_membership',
    'website_partner',
    'website_payment',
    'website_portal',
    'website_portal_sale',
    'website_project_issue',
    'website_project_issue_sheet',
    'website_quote',
    'website_rating_project_issue',
    'website_sale',
    'website_sale_delivery',
    'website_sale_digital',
    'website_sale_options',
    'website_sale_stock',
    'website_slides',
    'website_twitter',
}

odoo9e = {
    'account_bank_statement_import_ofx',
    'account_bank_statement_import_qif',
    'account_batch_deposit',
    'account_contract_dashboard',
    'account_deferred_revenue',
    'account_extension',
    'account_online_sync',
    'account_plaid',
    'account_reports',
    'account_reports_followup',
    'account_sepa',
    'account_yodlee',
    'crm_voip',
    'currency_rate_live',
    'delivery_dhl',
    'delivery_fedex',
    'delivery_temando',
    'delivery_ups',
    'delivery_usps',
    'hr_appraisal',
    'hr_holidays_gantt',
    'inter_company_rules',
    'l10n_ar_reports',
    'l10n_at_reports',
    'l10n_be_coda',
    'l10n_be_reports',
    'l10n_bo_reports',
    'l10n_br_reports',
    'l10n_ch_reports',
    'l10n_cl_reports',
    'l10n_co_reports',
    'l10n_de_skr03_reports',
    'l10n_de_skr04_reports',
    'l10n_do_reports',
    'l10n_es_reports',
    'l10n_et_reports',
    'l10n_fr_reports',
    'l10n_gr_reports',
    'l10n_hr_reports',
    'l10n_hu_reports',
    'l10n_in_reports',
    'l10n_jp_reports',
    'l10n_lu_reports',
    'l10n_ma_reports',
    'l10n_nl_reports',
    'l10n_no_reports',
    'l10n_pl_reports',
    'l10n_ro_reports',
    'l10n_sg_reports',
    'l10n_si_reports',
    'l10n_th_reports',
    'l10n_uk_reports',
    'l10n_us_check_printing',
    'l10n_uy_reports',
    'l10n_vn_reports',
    'mass_mailing_themes',
    'pos_loyalty',
    'print',
    'print_docsaway',
    'print_sale',
    'project_forecast',
    'project_timesheet_synchro',
    'sale_contract',
    'sale_contract_asset',
    'sale_ebay',
    'stock_barcode',
    'voip',
    'web',
    'web_gantt',
    'website_contract',
    'website_crm_score',
    'website_enterprise',
    'website_form_editor',
    'website_portal_followup',
    'website_sign',
    'website_version',
}

odoo9 = odoo9c | odoo9e



# -*- coding: utf-8 -*-
# © 2015 ACSONE SA/NV
# License LGPLv3 (http://www.gnu.org/licenses/lgpl-3.0-standalone.html)

import os
import unittest

from setuptools_odoo import git_postversion
from setuptools_odoo import manifest

from . import DATA_DIR


class TestGitPostversion(unittest.TestCase):

    def test_addon1(self):
        """ addon1 has 1 commit after version 8.0.1.0.0 """
        addon1_dir = os.path.join(DATA_DIR, 'addon1')
        version = git_postversion.get_git_postversion(addon1_dir)
        assert version == '8.0.1.0.0.99.dev1'

    def test_addon2(self):
        """ addon2 has not changed since 8.0.1.0.1 """
        addon2_dir = os.path.join(DATA_DIR, 'addon2')
        version = git_postversion.get_git_postversion(addon2_dir)
        assert version == '8.0.1.0.1'

    def test_addon2_uncommitted_version_change(self):
        """ test with a local uncommitted version change """
        addon2_dir = os.path.join(DATA_DIR, 'addon2')
        manifest_path = os.path.join(addon2_dir, '__openerp__.py')
        manifest = open(manifest_path).read()
        try:
            open(manifest_path, "w").write(manifest.replace("8.0.1.0.1",
                                                            "8.0.1.0.2"))
            version = git_postversion.get_git_postversion(addon2_dir)
            assert version == '8.0.1.0.2.dev1'
        finally:
            open(manifest_path, "w").write(manifest)

    def test_addon1_uncommitted_change(self):
        """ test with a local uncommitted change without version change """
        addon1_dir = os.path.join(DATA_DIR, 'addon1')
        manifest_path = os.path.join(addon1_dir, '__openerp__.py')
        manifest = open(manifest_path).read()
        try:
            open(manifest_path, "w").write(manifest.replace("summary",
                                                            "great summary"))
            version = git_postversion.get_git_postversion(addon1_dir)
            assert version == '8.0.1.0.0.99.dev2'
        finally:
            open(manifest_path, "w").write(manifest)

    def test_no_manifest(self):
        with self.assertRaises(manifest.NoManifestFound):
            git_postversion.get_git_postversion(DATA_DIR)



# -*- coding: utf-8 -*-
# © 2015 ACSONE SA/NV
# License LGPLv3 (http://www.gnu.org/licenses/lgpl-3.0-standalone.html)

import os
import subprocess
from pkg_resources import parse_version

from .manifest import (
    MANIFEST_NAMES, read_manifest, parse_manifest, NoManifestFound
)


def _run_git_command_exit_code(args, cwd=None):
    return subprocess.call(['git'] + args, cwd=cwd)


def _run_git_command_bytes(args, cwd=None):
    output = subprocess.check_output(['git'] + args, cwd=cwd)
    return output.strip()


def _run_git_command_lines(args, cwd=None):
    output = _run_git_command_bytes(args, cwd=cwd)
    return output.split('\n')


def is_git_controlled(path):
    return 0 == _run_git_command_exit_code(['rev-parse'], cwd=path)


def get_git_uncommitted(path):
    r = _run_git_command_exit_code(['diff', '--quiet', '--exit-code', '.'],
                                   cwd=path)
    return r != 0


def get_git_root(path):
    git_dir = _run_git_command_bytes(['rev-parse', '--git-dir'], cwd=path)
    return os.path.abspath(os.path.join(git_dir, '..'))


def git_log_iterator(path):
    """ yield commits using git log -- <dir> """
    N = 10
    count = 0
    while True:
        lines = _run_git_command_lines(['log', '--oneline',
                                        '-n', str(N),
                                        '--skip', str(count),
                                        '--', '.'], cwd=path)
        for line in lines:
            sha = line.split(' ', 1)[0]
            count += 1
            yield sha
        if len(lines) < N:
            break


def read_manifest_from_sha(sha, addon_dir):
    git_root = get_git_root(addon_dir)
    rel_addon_dir = os.path.relpath(addon_dir, git_root)
    for manifest_name in MANIFEST_NAMES:
        manifest_path = os.path.join(rel_addon_dir, manifest_name)
        try:
            s = _run_git_command_bytes(['show', sha + ':' + manifest_path],
                                       cwd=git_root)
        except subprocess.CalledProcessError:
            break
        try:
            return parse_manifest(s)
        except:
            # invalid manifest
            break
    raise NoManifestFound("no manifest found in %s:%s" % (sha, addon_dir))


def get_git_postversion(addon_dir):
    """ return the addon version number, with a developmental version increment
    if there were git commits in the addon_dir after the last version change.

    If the last change to the addon correspond to the version number in the
    manifest it is used as is for the python package version. Otherwise a
    counter is incremented for each commit and resulting version number has
    the following form: [8|9].0.x.y.z.1devN, N being the number of git
    commits since the version change.

    Note: we use .99.devN because:
    * pip ignores .postN  by design (https://github.com/pypa/pip/issues/2872)
    * x.y.z.devN is anterior to x.y.z

    Note: we don't put the sha1 of the commit in the version number because
    this is not PEP 440 compliant and is therefore misinterpreted by pip.
    """
    addon_dir = os.path.realpath(addon_dir)
    last_version = read_manifest(addon_dir).get('version', '0.0.0')
    last_version_parsed = parse_version(last_version)
    if not is_git_controlled(addon_dir):
        return last_version
    if get_git_uncommitted(addon_dir):
        uncommitted = True
        count = 1
    else:
        uncommitted = False
        count = 0
    last_sha = None
    for sha in git_log_iterator(addon_dir):
        try:
            manifest = read_manifest_from_sha(sha, addon_dir)
        except NoManifestFound:
            break
        version = manifest.get('version', '0.0.0')
        version_parsed = parse_version(version)
        if version_parsed != last_version_parsed:
            break
        if last_sha is None:
            last_sha = sha
        else:
            count += 1
    if not count:
        return last_version
    if last_sha:
        return last_version + ".99.dev%s" % count
    if uncommitted:
        return last_version + ".dev1"
    # if everything is committed, the last commit
    # must have the same version as current,
    # so last_sha must be set and we'll never reach this branch
    return last_version



# -*- coding: utf-8 -*-
# © 2015 ACSONE SA/NV
# License LGPLv3 (http://www.gnu.org/licenses/lgpl-3.0-standalone.html)

# map names of common python external dependencies in Odoo manifest files
# to actual python package names
EXTERNAL_DEPENDENCIES_MAP = {
    'Asterisk': 'py-Asterisk',
    'coda': 'pycoda',
    'cups': 'pycups',
    'dateutil': 'python-dateutil',
    'ldap': 'python-ldap',
    'serial': 'pyserial',
    'Crypto.Cipher.DES3': 'pycrypto',
}



# -*- coding: utf-8 -*-
# © 2015 ACSONE SA/NV
# License LGPLv3 (http://www.gnu.org/licenses/lgpl-3.0-standalone.html)

import os
import unittest

from setuptools_odoo.manifest import (
    read_manifest, is_installable_addon, NoManifestFound
)

from . import DATA_DIR


class TestManifest(unittest.TestCase):

    def test_read(self):
        addon_dir = os.path.join(DATA_DIR, 'addon1')
        manifest = read_manifest(addon_dir)
        assert 'version' in manifest

    def test_no_manifest(self):
        with self.assertRaises(NoManifestFound):
            read_manifest(DATA_DIR)

    def test_is_installable(self):
        addon1_dir = os.path.join(DATA_DIR, 'addon1')
        assert is_installable_addon(addon1_dir)
        addon3_dir = os.path.join(DATA_DIR, 'addon3_bad')
        assert not is_installable_addon(addon3_dir)



# -*- coding: utf-8 -*-
# © 2015 ACSONE SA/NV
# License LGPLv3 (http://www.gnu.org/licenses/lgpl-3.0-standalone.html)

import filecmp
import os
import shutil
import unittest

from setuptools_odoo import make_default_setup

from . import DATA_DIR


class TestMakeDefaultSetup(unittest.TestCase):

    def _assert_no_diff(self, dc):
        def _filter(l):
            return [i for i in l
                    if not i.endswith('.pyc') and
                    not i.endswith('.egg-info')]
        if dc.right.endswith('addon4'):
            # in addon4, we have a customized
            # setup.py to test depends and external_dependencies overrides
            return
        self.assertFalse(_filter(dc.left_only),
                         "missing %s in %s" % (dc.left_only, dc.right))
        self.assertFalse(_filter(dc.right_only),
                         "unexpected %s in %s" % (dc.right_only, dc.right))
        self.assertFalse(_filter(dc.diff_files),
                         "differing %s in %s" % (dc.diff_files, dc.right))
        for sub_dc in dc.subdirs.values():
            self._assert_no_diff(sub_dc)

    def test1(self):
        expected_dir = os.path.join(DATA_DIR, 'setup_reusable_addons')
        generated_dir = os.path.join(DATA_DIR, 'setup')
        make_default_setup.main(['--addons-dir', DATA_DIR, '-f'])
        dc = filecmp.dircmp(expected_dir, generated_dir)
        try:
            self._assert_no_diff(dc)
        finally:
            shutil.rmtree(generated_dir)


if __name__ == '__main__':
    unittest.main()



# -*- coding: utf-8 -*-
# © 2015 ACSONE SA/NV
# License LGPLv3 (http://www.gnu.org/licenses/lgpl-3.0-standalone.html)

import argparse
import os


from .core import ADDONS_NAMESPACE, is_installable_addon

SETUP_PY = """import setuptools

setuptools.setup(
    setup_requires=['setuptools-odoo'],
    odoo_addon=True,
)
"""

INIT_PY = """__import__('pkg_resources').declare_namespace(__name__)
"""

README = """To learn more about this directory, please visit
https://pypi.python.org/pypi/setuptools-odoo
"""

IGNORE = """# addons listed in this file are ignored by
# setuptools-odoo-make-default (one addon per line)
"""

IGNORE_FILENAME = '.setuptools-odoo-make-default-ignore'


def _load_ignore_file(ignore_path):
    ignore = set()
    if os.path.exists(ignore_path):
        for line in open(ignore_path):
            if line.startswith('#'):
                continue
            ignore.add(line.strip())
    return ignore


def make_default_setup_addon(addon_setup_dir, addon_dir, force):
    addon_name = os.path.basename(os.path.realpath(addon_dir))
    setup_path = os.path.join(addon_setup_dir, 'setup.py')
    if not os.path.exists(setup_path) or force:
        with open(setup_path, 'w') as f:
            f.write(SETUP_PY.format(addon_name=addon_name))
    odoo_addons_path = os.path.join(addon_setup_dir, ADDONS_NAMESPACE)
    if not os.path.exists(odoo_addons_path):
        os.mkdir(odoo_addons_path)
    init_path = os.path.join(odoo_addons_path, '__init__.py')
    if not os.path.exists(init_path) or force:
        with open(init_path, 'w') as f:
            f.write(INIT_PY)
    link_path = os.path.join(odoo_addons_path, addon_name)
    # symlink to the main addon directory so we have a canonical structure:
    # odoo_addons/addon_name/...
    if os.path.exists(link_path) and force:
        os.remove(link_path)
    if not os.path.exists(link_path):
        os.symlink(os.path.relpath(addon_dir, odoo_addons_path), link_path)


def make_default_setup_addons_dir(addons_dir, force):
    addons_setup_dir = os.path.join(addons_dir, 'setup')
    if not os.path.exists(addons_setup_dir):
        os.mkdir(addons_setup_dir)
    readme_path = os.path.join(addons_setup_dir, 'README')
    if not os.path.exists(readme_path):
        with open(readme_path, "w") as f:
            f.write(README)
    ignore_path = os.path.join(addons_setup_dir, IGNORE_FILENAME)
    if not os.path.exists(ignore_path):
        with open(ignore_path, "w") as f:
            f.write(IGNORE)
    ignore = _load_ignore_file(ignore_path)
    for addon_name in os.listdir(addons_dir):
        if addon_name in ignore:
            continue
        addon_dir = os.path.join(addons_dir, addon_name)
        if not is_installable_addon(addon_dir):
            continue
        addon_setup_dir = os.path.join(addons_setup_dir, addon_name)
        if not os.path.exists(addon_setup_dir):
            os.mkdir(addon_setup_dir)
        make_default_setup_addon(addon_setup_dir, addon_dir, force)


def main(args=None):
    parser = argparse.ArgumentParser(
        description='Generate default setup.py for all addons in an '
                    'Odoo addons directory'
    )
    parser.add_argument('--addons-dir', '-d', required=True)
    parser.add_argument('--force', '-f', action='store_true')
    args = parser.parse_args(args)
    make_default_setup_addons_dir(args.addons_dir, args.force)


if __name__ == '__main__':
    import sys
    main(sys.argv[1:])



{
    'name': 'addon 2',
    'summary': 'addon 2 summary',
    'version': '8.0.1.0.1',
    'depends': [
        'addon1',
    ],
    'external_dependencies': {
        'python': [
            'dateutil',
        ],
    },
}



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# © 2015 ACSONE SA/NV
# License LGPLv3 (http://www.gnu.org/licenses/lgpl-3.0-standalone.html)

import setuptools

setuptools.setup(
    name='setuptools-odoo',
    version='1.0.0b5',
    description='A library to help package Odoo addons with setuptools',
    long_description='\n'.join((
        open('README.rst').read(),
        open('CHANGES.rst').read(),
    )),
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: '
        'GNU Lesser General Public License v3 (LGPLv3)',
        'Operating System :: POSIX',  # because we use symlinks
        'Programming Language :: Python :: 2.7',
    ],
    license='LGPLv3',
    author='ACSONE SA/NV',
    author_email='info@acsone.eu',
    url='http://github.com/acsone/setuptools-odoo',
    packages=[
        'setuptools_odoo',
    ],
    install_requires=[
        'setuptools',
        'setuptools-git',
    ],
    test_suite='tests',
    entry_points={
        'console_scripts': [
            "setuptools-odoo-make-default="
            "setuptools_odoo.make_default_setup:main",
        ],
        "distutils.setup_keywords": [
            "odoo_addon = setuptools_odoo.setup_keywords:odoo_addon",
            "odoo_addons = setuptools_odoo.setup_keywords:odoo_addons",
        ],
    },
)



# -*- coding: utf-8 -*-
# © 2015 ACSONE SA/NV
# License LGPLv3 (http://www.gnu.org/licenses/lgpl-3.0-standalone.html)

import ast
import os

MANIFEST_NAMES = ('__openerp__.py', '__odoo__.py', '__terp__.py')


class NoManifestFound(Exception):
    pass


def get_manifest_path(addon_dir):
    for manifest_name in MANIFEST_NAMES:
        manifest_path = os.path.join(addon_dir, manifest_name)
        if os.path.isfile(manifest_path):
            return manifest_path


def parse_manifest(s):
    return ast.literal_eval(s)


def read_manifest(addon_dir):
    manifest_path = get_manifest_path(addon_dir)
    if not manifest_path:
        raise NoManifestFound("no Odoo manifest found in %s" % addon_dir)
    return parse_manifest(open(manifest_path).read())


def is_installable_addon(addon_dir, unless_auto_installable=False):
    try:
        manifest = read_manifest(addon_dir)
        r = manifest.get('installable', True)
        if unless_auto_installable:
            r = r and not manifest.get('auto_install', False)
        return r
    except:
        return False



# -*- coding: utf-8 -*-
# © 2015 ACSONE SA/NV
# License LGPLv3 (http://www.gnu.org/licenses/lgpl-3.0-standalone.html)
import os
import unittest

import setuptools_odoo

from . import DATA_DIR


class TestInstallRequires(unittest.TestCase):
    """ Test the install_requires... public api """

    def test_addons_dir(self):
        r = setuptools_odoo.get_install_requires_odoo_addons(DATA_DIR)
        self.assertEquals(r, ['astropy',
                              'odoo>=8.0a,<9.0a',
                              'python-dateutil'])

    def test_addon1(self):
        addon_dir = os.path.join(DATA_DIR, 'addon1')
        r = setuptools_odoo.get_install_requires_odoo_addon(addon_dir)
        self.assertEquals(r, ['odoo>=8.0a,<9.0a'])

    def test_addon2(self):
        addon_dir = os.path.join(DATA_DIR, 'addon2')
        r = setuptools_odoo.get_install_requires_odoo_addon(addon_dir)
        self.assertEquals(r, ['odoo-addon-addon1>=8.0a,<9.0a',
                              'odoo>=8.0a,<9.0a',
                              'python-dateutil'])


if __name__ == '__main__':
    unittest.main()
